@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.servicecontrol_v1.types import check_error
 from google.cloud.servicecontrol_v1.types import service_controller
 from .transports.base import ServiceControllerTransport, DEFAULT_CLIENT_INFO
@@ -334,17 +336,14 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def check(
         self,
-        request: service_controller.CheckRequest = None,
+        request: Union[service_controller.CheckRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service_controller.CheckResponse:
@@ -369,7 +368,7 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         `Cloud IAM <https://cloud.google.com/iam>`__.
 
         Args:
-            request (google.cloud.servicecontrol_v1.types.CheckRequest):
+            request (Union[google.cloud.servicecontrol_v1.types.CheckRequest, dict]):
                 The request object. Request message for the Check
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -404,9 +403,9 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
 
     def report(
         self,
-        request: service_controller.ReportRequest = None,
+        request: Union[service_controller.ReportRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service_controller.ReportResponse:
@@ -430,7 +429,7 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         `Google Cloud IAM <https://cloud.google.com/iam>`__.
 
         Args:
-            request (google.cloud.servicecontrol_v1.types.ReportRequest):
+            request (Union[google.cloud.servicecontrol_v1.types.ReportRequest, dict]):
                 The request object. Request message for the Report
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -463,6 +462,19 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
