@@ -30,6 +30,14 @@ __protobuf__ = proto.module(
 
 class LogEntry(proto.Message):
     r"""An individual log entry.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Required. The log to which this log entry belongs. Examples:
@@ -62,12 +70,15 @@ class LogEntry(proto.Message):
             The log entry payload, represented as a protocol buffer that
             is expressed as a JSON object. The only accepted type
             currently is [AuditLog][google.cloud.audit.AuditLog].
+            This field is a member of `oneof`_ ``payload``.
         text_payload (str):
             The log entry payload, represented as a
             Unicode string (UTF-8).
+            This field is a member of `oneof`_ ``payload``.
         struct_payload (google.protobuf.struct_pb2.Struct):
             The log entry payload, represented as a
             structure that is expressed as a JSON object.
+            This field is a member of `oneof`_ ``payload``.
         operation (google.cloud.servicecontrol_v1.types.LogEntryOperation):
             Optional. Information about an operation
             associated with the log entry, if applicable.
